@@ -977,6 +977,12 @@ LIBTCCAPI TCCState *tcc_new(const char *init_lib_path)
 # if defined(__FreeBSD_kernel__)
     tcc_define_symbol(s, "__FreeBSD_kernel__", NULL);
 # endif
+#endif
+
+#if defined(__ANDROID__)
+#  define str(s) #s
+    tcc_define_symbol(s, "__ANDROID__", str(__ANDROID__));
+#  undef str
 #endif
 
     /* TinyCC & gcc defines */
